==> dinolib-0.9.3.tar.gz: dinolib-0.9.3/lib/dino_tpl2.php <==
<?php {
  /*
   * $Id: dino_tpl2.php,v 1.22 2003/06/17 10:13:03 tumf Exp $
   * Copyright (c) 2002-2003 Dino Co.,Ltd.
   */

  /**
   * smarty  ƥץ졼ȥ󥸥
   * 
   * 
   * @package Dino_Tpl2
   * @author tumf
   */

  require_once(SMARTY_DIR."/Smarty.class.php");
  require_once("dino_browser.php");

  /**
   * ॿrequire_onceԤ
   *
   *
   *
   * @access public
   * @package Dino_Tpl2
   * @author tumf
   */
  function dinolib_load_smarty_plugins($plugins){
    foreach($plugins as $name => $type){
      require_once("tpl2/smarty_plugins/function.dino_".$name.".php");
    }
  }

  /**
   * smartyȥॿ
   * 
   * (*)Dino_Tplȸߴ뤿ᡢ饹̾ʸˤʤäƤޤ
   * @package Dino_Tpl2
   * @author tumf
   */
  class dino_tpl extends Smarty {

    /**
     * ɤץ饰ΰ
     */
    var $dino_plugins=array();

    /**
     * 󥹥ȥ饯
     *
     */
    function dino_tpl(){
      parent::Smarty();
      $this->dino_plugins=
	array(
	      "auth"=>"function",
	      "listnavi"=>"function",
	      "trancate"=>"block",
	      "mail"=>"block",
	      "init_get_calendar"=>"function",
	      "get_calendar"=>"function",
	      "tpl_form"=>"function",
	      "number_format"=>"modifier",
	      "ksave"=>array("block","modifier"),
	      "mbenc"=>array("modifier"),
  	      "escape" => array("function"), // block Ȥ...SmartyǤϡfunction /block Ƚ̤ʤ餷
	      "emoji"=>"function",
	      "contents" =>"function"
	      );
    }


    /**
     * dinolib ƳSmartyΥॿϿ
     * 
     * $this->dino_plugins ˽äơɬפʥեɤ롣
     * @access public
     */
    function register_dinolib_plugins(){
      dinolib_load_smarty_plugins($this->dino_plugins);
      // smary  dino lib ॿɲ
      foreach($this->dino_plugins as $name => $type){
	if(is_array($type)){
	  foreach($type as $n => $t){
	    $register="register_".$t;
	    $this->$register("dino_".$name,"smarty_".$t."_dino_".$name);
	  }
	}else{
	  $register="register_".$type;
	  $this->$register("dino_".$name,"smarty_".$type."_dino_".$name);
	}
      }
      
      $this->register_function("tmpl_form","smarty_function_dino_tpl_form"); // obsolate!
    }

    /**
     * User Agent ˥ƥץ졼Ȥ񤭴
     *
     * Dino_BrowserѤ
     *
     * @access public
     */
    function switch_template(){
      $br=new Dino_Browser;
      if($br->is_handy()){
	return "/i"; // for i-mode template
      }
      return ""; // PC(or default template);
    }

    /**
     * ƥץ졼ͤΥå
     *
     * Dino_Tpl ȤݤĤHelper function
     *
     * @access public
     */
    function set_var($var){
      if(is_array($var)){
	reset($var);
	while(list($key,$val)=each($var)){
	  if(!is_int($key)){
	    $this->assign_vars[strtr($key,".","_")]
	      =$val; 
	  }
	}
      }
    }

    /**
     * ƥץ졼ͤɲ
     *
     * Dino_Tpl ȤݤĤHelper function
     *
     * @access public
     */
    function add_var($var){
      if(is_array($var)){
	reset($var);
	while(list($key,$val)=each($var)){
	  if(!is_int($key)){
	    // key  . -> _ Ѵ
	    $this->assign_vars[strtr($key,".","_")][]
	      =$val; 
	  }
	}
      }
    }

    /**
     * set_var add_var Τ ޤȤƥ
     *
     * Dino_Tpl ȤݤĤHelper function
     *
     *
     * @access public
     */
    function parse(){
      $this->assign($this->assign_vars);
      return ;
    }

    /**
     * ƥץ졼Ȥȥե४֥ȤΥХ
     *
     * δؿϸߴΤ˼äƤΤǤ
     * set_tpl_form() ȤäƤ
     *
     * objsolate! use set_tpl_form();
     * assign for template function tmpl_form
     *
     * @access public
     */
    function set_tmpl_form(&$f) {
      return $this->set_tpl_form(&$f);
    }

    /**
     * ƥץ졼Ȥȥե४֥ȤΥХ
     *
     * ե४֥Ȥȥƥץ졼ȥ֥Ȥ
     * ӤĤ
     *
     * @access public
     */
    function set_tpl_form(&$f,$name="none") {
      $this->_tpl_vars['__form_obj'][$name] = $f;
    }

    /**
     * ƥץ졼Ȥȥե४֥ȤΥХ
     *
     * ե४֥Ȥȥƥץ졼ȥ֥Ȥ
     * ӤĤ
     *
     * @access public
     */
    function set_tpl_page(&$page) {
      $this->assign_by_ref('__page_obj', $page);
    }

  }

} ?>

==> dinolib-0.9.4a.tar.gz: dinolib-0.9.4a/lib/dino_tpl2.php <==
<?php {
  /*
   * $Id: dino_tpl2.php,v 1.25 2003/11/30 16:26:20 hanawa Exp $
   * Copyright (c) 2002-2003 Dino Co.,Ltd.
   */

  /**
   * smarty  ƥץ졼ȥ󥸥
   * 
   * 
   * @package Dino_Tpl2
   * @author tumf
   */

  require_once(SMARTY_DIR."/Smarty.class.php");
  require_once("dino_browser.php");

  /**
   * ॿrequire_onceԤ
   *
   *
   *
   * @access public
   * @package Dino_Tpl2
   * @author tumf
   */
  function dinolib_load_smarty_plugins($plugins){
    foreach($plugins as $name => $type){
      require_once("tpl2/smarty_plugins/function.dino_".$name.".php");
    }
  }

  /**
   * smartyȥॿ
   * 
   * (*)Dino_Tplȸߴ뤿ᡢ饹̾ʸˤʤäƤޤ
   * @package Dino_Tpl2
   * @author tumf
   */
  class dino_tpl extends Smarty {

    /**
     * ɤץ饰ΰ
     */
    var $dino_plugins=array();

    /**
     * 󥹥ȥ饯
     *
     */
    function dino_tpl(){
      parent::Smarty();
      $this->dino_plugins=
	array(
	      "auth"=>"function",
	      "listnavi"=>"function",
	      "trancate"=>"block",
	      "contents_format"=>"block",
	      "mail"=>"block",
	      "init_get_calendar"=>"function",
	      "get_calendar"=>"function",
	      "tpl_form"=>"function",
	      "number_format"=>"modifier",
	      "ksave"=>array("block","modifier"),
	      "mbenc"=>array("modifier"),
  	      "escape" => array("function"), // block Ȥ...SmartyǤϡfunction /block Ƚ̤ʤ餷
	      "emoji"=>"function",
	      "contents" =>"function",
	      "read_image"=>"function"
	      );
    }


    /**
     * dinolib ƳSmartyΥॿϿ
     * 
     * $this->dino_plugins ˽äơɬפʥեɤ롣
     * @access public
     */
    function register_dinolib_plugins(){
      dinolib_load_smarty_plugins($this->dino_plugins);
      // smary  dino lib ॿɲ
      foreach($this->dino_plugins as $name => $type){
	if(is_array($type)){
	  foreach($type as $n => $t){
	    $register="register_".$t;
	    $this->$register("dino_".$name,"smarty_".$t."_dino_".$name);
	  }
	}else{
	  $register="register_".$type;
	  $this->$register("dino_".$name,"smarty_".$type."_dino_".$name);
	}
      }
      
      $this->register_function("tmpl_form","smarty_function_dino_tpl_form"); // obsolate!
    }

    /**
     * User Agent ˥ƥץ졼Ȥ񤭴
     *
     * Dino_BrowserѤ
     *
     * @access public
     */
    function switch_template(){
      $br=new Dino_Browser;
      if($br->is_handy()){
	return "/i"; // for i-mode template
      }
      return ""; // PC(or default template);
    }

    /**
     * ƥץ졼ͤΥå
     *
     * Dino_Tpl ȤݤĤHelper function
     *
     * @access public
     */
    function set_var($var){
      if(is_array($var)){
	reset($var);
	while(list($key,$val)=each($var)){
	  if(!is_int($key)){
	    $this->assign_vars[strtr($key,".","_")] = $val;
	  }
	}
      }
    }

    /**
     * ƥץ졼ͤɲ
     *
     * Dino_Tpl ȤݤĤHelper function
     *
     * @access public
     */
    function add_var($var){
      if(is_array($var)){
	reset($var);
	while(list($key,$val)=each($var)){
	  if(!is_int($key)){
	    // key  . -> _ Ѵ
	    $this->assign_vars[strtr($key,".","_")][]
	      =$val; 
	  }
	}
      }
    }

    /**
     * set_var add_var Τ ޤȤƥ
     *
     * Dino_Tpl ȤݤĤHelper function
     *
     *
     * @access public
     */
    function parse(){
      $this->assign($this->assign_vars);
      return ;
    }

    /**
     * ƥץ졼Ȥȥե४֥ȤΥХ
     *
     * δؿϸߴΤ˼äƤΤǤ
     * set_tpl_form() ȤäƤ
     *
     * objsolate! use set_tpl_form();
     * assign for template function tmpl_form
     *
     * @access public
     */
    function set_tmpl_form(&$f) {
      return $this->set_tpl_form(&$f);
    }

    /**
     * ƥץ졼Ȥȥե४֥ȤΥХ
     *
     * ե४֥Ȥȥƥץ졼ȥ֥Ȥ
     * ӤĤ
     *
     * @access public
     */
    function set_tpl_form(&$f,$name="none") {
      $this->_tpl_vars['__form_obj'][$name] = $f;
    }

    /**
     * ƥץ졼Ȥȥե४֥ȤΥХ
     *
     * ե४֥Ȥȥƥץ졼ȥ֥Ȥ
     * ӤĤ
     *
     * @access public
     */
    function set_tpl_page(&$page) {
      $this->assign_by_ref('__page_obj', $page);
    }

  }

} ?>
